==> apache-geode-1.4.0-src.zip: apache-geode-1.4.0-src/geode-core/src/main/java/org/apache/geode/internal/cache/tier/sockets/MessageIdExtractor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 *
 */
package org.apache.geode.internal.cache.tier.sockets;

import org.apache.geode.internal.i18n.LocalizedStrings;
import org.apache.geode.security.AuthenticationRequiredException;

public class MessageIdExtractor {
  public long getUniqueIdFromMessage(Message requestMessage, HandShake handshake, long connectionId)
      throws AuthenticationRequiredException {
    AuthIds aIds = getAuthIdsFromMessage(requestMessage, handshake);
    if (connectionId != aIds.getConnectionId()) {
      throw new AuthenticationRequiredException(
          LocalizedStrings.HandShake_NO_SECURITY_CREDENTIALS_ARE_PROVIDED.toLocalizedString());
    }
    return aIds.getUniqueId();
  }

  private AuthIds getAuthIdsFromMessage(Message requestMessage, HandShake handshake)
      throws AuthenticationRequiredException {
    try {
      byte[] secureBytes = requestMessage.getSecureBytes();
      secureBytes = handshake.decryptBytes(secureBytes);
      return new AuthIds(secureBytes);
    } catch (Exception ex) {
      throw new AuthenticationRequiredException(
          LocalizedStrings.HandShake_NO_SECURITY_CREDENTIALS_ARE_PROVIDED.toLocalizedString(), ex);
    }
  }
}

==> apache-geode-1.7.0-src.zip: apache-geode-1.7.0-src/geode-core/src/main/java/org/apache/geode/internal/cache/tier/sockets/MessageIdExtractor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 *
 */
package org.apache.geode.internal.cache.tier.sockets;

import org.apache.geode.internal.cache.tier.Encryptor;
import org.apache.geode.internal.i18n.LocalizedStrings;
import org.apache.geode.security.AuthenticationRequiredException;

public class MessageIdExtractor {
  public long getUniqueIdFromMessage(Message requestMessage, Encryptor handshake, long connectionId)
      throws AuthenticationRequiredException {
    AuthIds aIds = getAuthIdsFromMessage(requestMessage, handshake);
    if (connectionId != aIds.getConnectionId()) {
      throw new AuthenticationRequiredException(
          LocalizedStrings.HandShake_NO_SECURITY_CREDENTIALS_ARE_PROVIDED.toLocalizedString());
    }
    return aIds.getUniqueId();
  }

  private AuthIds getAuthIdsFromMessage(Message requestMessage, Encryptor handshake)
      throws AuthenticationRequiredException {
    try {
      byte[] secureBytes = requestMessage.getSecureBytes();
      secureBytes = handshake.decryptBytes(secureBytes);
      return new AuthIds(secureBytes);
    } catch (Exception ex) {
      throw new AuthenticationRequiredException(
          LocalizedStrings.HandShake_NO_SECURITY_CREDENTIALS_ARE_PROVIDED.toLocalizedString(), ex);
    }
  }
}
